@@ -39,6 +39,8 @@ from .zfile import save_excel_items
 from .zfile import save_items_to_csv
 from .zfile import convert_csv_to_xlsx
 from .zfile import convert_xlsx_to_csv
+from .zfile import convert_jsonl_to_xlsx
+from .zfile import convert_xlsx_to_jsonl
 
 
 # zdefinition
@@ -108,6 +110,7 @@ from .zjson import jsondumps
 from .ztime import get_date
 from .ztime import get_today
 from .ztime import get_month
+from .ztime import get_now
 
 
 # zalioss
